@@ -1,6 +1,6 @@
 package Address::PostCode::Australia::Params;
 
-$Address::PostCode::Australia::Params::VERSION = '0.05';
+$Address::PostCode::Australia::Params::VERSION = '0.06';
 
 =head1 NAME
 
@@ -8,7 +8,11 @@ Address::PostCode::Australia::Params - Placeholder for parameters for Address::P
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
+
+=head1 DESCRIPTION
+
+B<FOR INTERNAL USE ONLY>
 
 =cut
 
@@ -16,10 +20,9 @@ use 5.006;
 use strict; use warnings;
 use Data::Dumper;
 
-use vars qw(@ISA @EXPORT @EXPORT_OK);
-
+use vars qw(@ISA @EXPORT_OK);
 require Exporter;
-@ISA = qw(Exporter);
+@ISA       = qw(Exporter);
 @EXPORT_OK = qw(validate);
 
 sub check_num {
@@ -111,8 +114,8 @@ L<http://search.cpan.org/dist/Address-PostCode-Australia/>
 
 Copyright (C) 2014 - 2015 Mohammad S Anwar.
 
-This  program  is  free software; you can redistribute it and/or modify it under
-the  terms  of the the Artistic License (2.0). You may obtain a copy of the full
+This program  is  free software; you can redistribute it and / or modify it under
+the  terms  of the the Artistic License (2.0). You may obtain  a copy of the full
 license at:
 
 L<http://www.perlfoundation.org/artistic_license_2_0>
